# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), 
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.17] - 2023-06-04
### Added
- Support the command line argument `--output-file`
### Changed
- Rename the command line argument `--path` with `--asset-path`

## [0.0.6] - 2023-06-03
### Added
- Initial import
